==> django_sb_codefield-0.1.0.tar.gz: django_sb_codefield-0.1.0/README.md <==
![Community-Project](https://gitlab.com/softbutterfly/open-source/open-source-office/-/raw/master/banners/softbutterfly-open-source--banner--community-project.png)

![PyPI - Supported versions](https://img.shields.io/pypi/pyversions/django-sb-codefield)
![PyPI - Package version](https://img.shields.io/pypi/v/django-sb-codefield)
![PyPI - Downloads](https://img.shields.io/pypi/dm/django-sb-codefield)
![PyPI - MIT License](https://img.shields.io/pypi/l/django-sb-codefield)

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/fe5644bd3a114473879a304321a68f3e)](https://app.codacy.com/gl/softbutterfly/django-sb-codefield/dashboard?utm_source=gl&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)

# Wagtail FontAwesome

Use FontAwesome icons in Wagtail admin.

## Requirements

- Python higher than o equals to 3.8.1 and lower than 4.0.0
- Django lower than 5.0.0
- django-codemirror2 lower than 1.0.0

## Install

```bash
pip install django-sb-codefield
```

## Usage

Add `codemirror2` and `django_sb_codefield` to your `INSTALLED_APPS` settings

```
INSTALLED_APPS = [
  # ...
  "codemirror2",
  "django_sb_codefield",
]
```

## Docs

- [Ejemplos](https://gitlab.com/softbutterfly/open-source/django-sb-codefield/-/wikis)
- [Wiki](https://gitlab.com/softbutterfly/open-source/django-sb-codefield/-/wikis)

## Changelog

All changes to versions of this library are listed in the [change history](CHANGELOG.md).

## Development

Check out our [contribution guide](CONTRIBUTING.md).

## Contributors

See the list of contributors [here](https://gitlab.com/softbutterfly/open-source/django-sb-codefield/-/graphs/develop).

==> django_sb_codefield-0.3.0.tar.gz: django_sb_codefield-0.3.0/README.md <==
![Community-Project](https://gitlab.com/softbutterfly/open-source/open-source-office/-/raw/master/banners/softbutterfly-open-source--banner--community-project.png)

![PyPI - Supported versions](https://img.shields.io/pypi/pyversions/django-sb-codefield)
![PyPI - Package version](https://img.shields.io/pypi/v/django-sb-codefield)
![PyPI - Downloads](https://img.shields.io/pypi/dm/django-sb-codefield)
![PyPI - MIT License](https://img.shields.io/pypi/l/django-sb-codefield)

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/fe5644bd3a114473879a304321a68f3e)](https://app.codacy.com/gl/softbutterfly/django-sb-codefield/dashboard?utm_source=gl&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)

# Django CodeField

Use codemirror2 widget directly in Django models, forms and admin.

## Requirements

- Python 3.8.1 or higher but lower than 4.0.0
- Django lower than 5.0.0
- django-codemirror2 lower than 1.0.0

## Install

```bash
pip install django-sb-codefield
```

## Usage

Add `codemirror2` and `django_sb_codefield` to your `INSTALLED_APPS` settings

```
INSTALLED_APPS = [
  # ...
  "codemirror2",
  "django_sb_codefield",
]
```

## Docs

- [Ejemplos](https://gitlab.com/softbutterfly/open-source/django-sb-codefield/-/wikis)
- [Wiki](https://gitlab.com/softbutterfly/open-source/django-sb-codefield/-/wikis)

## Changelog

All changes to versions of this library are listed in the [change history](CHANGELOG.md).

## Development

Check out our [contribution guide](CONTRIBUTING.md).

## Contributors

See the list of contributors [here](https://gitlab.com/softbutterfly/open-source/django-sb-codefield/-/graphs/develop).
